--------------------------------
--      Module Prototype      --
--------------------------------

Necronomicon.modulePrototype.core = Necronomicon
Necronomicon.modulePrototype.revision = 1

function Necronomicon.modulePrototype:OnInitialize()
	-- Unconditionally register, this shouldn't happen from any other place
	-- anyway.
	self.core:RegisterModule(self.name, self)
end

function Necronomicon.modulePrototype:IsRegistered()
	return self.registered
end

function Necronomicon.modulePrototype:Warn( msg )
	if not msg then return end
	self.core:Print( msg )
end

function Necronomicon.modulePrototype:Message( msg )
	if not msg then return end
	if (GetNumRaidMembers() > 0) then
		SendChatMessage(msg, "RAID")
	elseif (GetNumPartyMembers() > 0) then
		SendChatMessage(msg, "PARTY")
	else
		SendChatMessage(msg, "SAY")
	end
end

function Necronomicon.modulePrototype:RegisterSpell( spell )
	self.core.spelllist[spell] = true
end

function Necronomicon.modulePrototype:RegisterItem( itemid )
	self.core.itemlist[itemid] = true
	self.core.itemcount[itemid] = 0
end

function Necronomicon.modulePrototype:HasSpell( spell )
	return self.core.hasspell[spell]
end

function Necronomicon.modulePrototype:OnDisable()
	if self.button then
		self.button:Hide()
	end
end

function Necronomicon.modulePrototype:CreateButton()
	if not self.button then
		self.button = CreateFrame("Button", self.name.."Button", UIParent, "SecureActionButtonTemplate")
	end
	local button = self.button

	button:Hide()
	button.owner = self
	button:SetWidth( 32 )
	button:SetHeight( 32 )
	button:ClearAllPoints()
	button:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	button:EnableMouse(true)
	button:RegisterForDrag("LeftButton")
	button:RegisterForClicks("AnyUp")
	button:SetMovable(true)
	button:SetScript("OnDragStart", function() if not InCombatLockdown() and IsAltKeyDown() then this:StartMoving() end end)
	button:SetScript("OnDragStop", function() if not InCombatLockdown() then this:StopMovingOrSizing() this.owner:SavePosition() end end)

	button.background = button:CreateTexture( nil, "BACKGROUND")
	button.background:SetWidth( 32 )
	button.background:SetHeight( 32 )
	button.background:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)

	self:RestorePosition()
end

function Necronomicon.modulePrototype:SavePosition()
	local f = self.button
	local s = f:GetEffectiveScale()

	self.db.profile.posx = f:GetLeft() * s
	self.db.profile.posy = f:GetTop() * s
end

function Necronomicon.modulePrototype:RestorePosition()
	local x = self.db.profile.posx
	local y = self.db.profile.posy

	if not x or not y then return end

	local f = self.button
	local s = f:GetEffectiveScale()

	f:ClearAllPoints()
	f:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", x / s, y / s)
end
